package betterquesting.api2.client.gui.resources.textures;

import betterquesting.api.utils.BigItemStack;
import betterquesting.api.utils.RenderUtils;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.resources.colors.GuiColorStatic;
import betterquesting.api2.client.gui.resources.colors.IGuiColor;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import net.minecraft.client.Minecraft;
import net.minecraft.util.ResourceLocation;
import org.lwjgl.opengl.GL11;

/* loaded from: betterquesting_api2_client_gui_resources_textures.jar:betterquesting/api2/client/gui/resources/textures/ItemTexture.class */
public class ItemTexture implements IGuiTexture {
    private static final IGuiColor defColor = new GuiColorStatic(255, 255, 255, 255);
    private final BigItemStack stack;
    private final boolean showCount;
    private final boolean keepAspect;
    private float zDepth;
    private final IGuiRect bounds;

    public ItemTexture(BigItemStack stack) {
        this(stack, false, true);
    }

    public ItemTexture(BigItemStack stack, boolean showCount, boolean keepAspect) {
        this.zDepth = 16.0f;
        this.bounds = new GuiRectangle(0, 0, 16, 16);
        this.stack = stack;
        this.showCount = showCount;
        this.keepAspect = keepAspect;
    }

    public ItemTexture setDepth(float z) {
        this.zDepth = z;
        return this;
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public void drawTexture(int x, int y, int width, int height, float zLevel, float partialTick) {
        drawTexture(x, y, width, height, zLevel, partialTick, defColor);
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public void drawTexture(int x, int y, int width, int height, float zLevel, float partialTick, IGuiColor color) {
        if (width <= 0 || height <= 0) {
            return;
        }
        float sx = width / 16.0f;
        float sy = height / 16.0f;
        double dx = 0.0d;
        double dy = 0.0d;
        if (this.keepAspect) {
            float sa = Math.min(sx, sy);
            dx = Math.floor((sx - sa) * 8.0f);
            dy = Math.floor((sy - sa) * 8.0f);
            sx = sa;
            sy = sa;
        }
        GL11.glPushMatrix();
        GL11.glTranslated(x + dx, y + dy, 0.0d);
        GL11.glScalef(sx, sy, 1.0f);
        color.applyGlColor();
        RenderUtils.RenderItemStack(Minecraft.func_71410_x(), this.stack.getBaseStack(), 0, 0, this.zDepth, (!this.showCount || this.stack.stackSize <= 1) ? "" : "" + this.stack.stackSize, -1);
        GL11.glPopMatrix();
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public ResourceLocation getTexture() {
        return PresetTexture.TX_NULL;
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public IGuiRect getBounds() {
        return this.bounds;
    }
}
